({
	insertTableTitle: "Inserare tabel",
	modifyTableTitle: "Modificare tabel",
	rows: "Rânduri:",
	columns: "Coloane:",
	align: "Aliniere:",
	cellPadding: "Padding celulă:",
	cellSpacing: "Spaţiere celulă:",
	tableWidth: "Lăţime tabelă:",
	backgroundColor: "Culoare de fundal:",
	borderColor: "Coloare de bordură:",
	borderThickness: "Grosime de bordură:",
	percent: "procent",
	pixels: "pixeli",
	"default": "implicit",
	left: "stânga",
	center: "centru",
	right: "dreapta",
	buttonSet: "Setare", // translated elsewhere?
	buttonInsert: "Inserare",
	buttonCancel: "Anulare",

	selectTableLabel: "Selectare tabelă",
	insertTableRowBeforeLabel: "Adăugare rând înainte",
	insertTableRowAfterLabel: "Adăugare rând după",
	insertTableColumnBeforeLabel: "Adăugare coloană înainte",
	insertTableColumnAfterLabel: "Adăugare coloană după",
	deleteTableRowLabel: "Ştergere rând",
	deleteTableColumnLabel: "Ştergere coloană"
})
	

